#ifndef _P_SMTP__INTERNAL_H
#define _P_SMTP__INTERNAL_H
#include <plib/smtp.h>

__BEGIN_DECLS

void smtp_set_read_timeout(struct smtp *, long);
ssize_t smtp_read(const struct smtp *, void *, size_t);
SMTP_STATUS_CODE smtp_write(struct smtp *, const char *, size_t);
SMTP_STATUS_CODE smtp_puts(struct smtp *, const char *);
SMTP_STATUS_CODE smtp_puts_terminate(struct smtp *, const char *);
void smtp_puts_dbg(struct smtp *,  const char *,  const char *);

SMTP_STATUS_CODE smtp_printf(struct smtp * smtp, const char * fmt, ...);
SMTP_STATUS_CODE smtp_print_mime_attachment(struct smtp *, const char *, const val_t *);
SMTP_STATUS_CODE smtp_append_address_to_header(struct smtp *, SMTP_ADDRESS_TYPE, const char *);
ssize_t smtp_str_getdelimfd_read(struct str_getdelimfd *);

__END_DECLS
#endif